/**
 * JASMINe
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MonitoringModelLocator.as 4798 2009-08-07 12:30:47Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jasmine.monitoring.eos.monitoring.model
{
import com.adobe.cairngorm.model.ModelLocator;

import mx.collections.ArrayCollection;
import mx.rpc.events.FaultEvent;

import org.ow2.jasmine.monitoring.eos.monitoring.business.ILoadDatasDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.ILoadDataBaseDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.ILoadFileDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.IStartMonitoringDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.IStopMonitoringDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.LoadDatasDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.LoadDataBaseDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.LoadFileDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.StartMonitoringDelegate;
import org.ow2.jasmine.monitoring.eos.monitoring.business.StopMonitoringDelegate;

/**
 * @author Guillaume Renault
 */
[Bindable]
public class MonitoringModelLocator implements ModelLocator
{

    // private

    private var configurationObj:XML = null;

    /**
    * An ArrayCollection of ArrayCollections of String
    */
    private var providersObj:ArrayCollection = null;

    private var onErrorObj:FaultEvent = null;

    /**
    * Unique instance of this locator.
    */
    private static var model:MonitoringModelLocator = null;

    //[ArrayElementType(JasmineMessageEventVO)]

    // delegate unique instances

    private var loadFileDelegate:ILoadFileDelegate = null;

    private var loadDatasDelegate:ILoadDatasDelegate = null;
    
    private var loadDataBaseDelegate:ILoadDataBaseDelegate = null;

    private var startMonitoringDelegate:IStartMonitoringDelegate = null;

    private var stopMonitoringDelegate:IStopMonitoringDelegate = null;

    // functions
    public function MonitoringModelLocator()
    {
        super();

        if (model != null) {
            throw new Error("Only one LaunchCommandModellocator has to be set");
        }
    }

    public static function getInstance() : MonitoringModelLocator {
        if (MonitoringModelLocator.model == null) {
            MonitoringModelLocator.model = new MonitoringModelLocator();
        }

        return MonitoringModelLocator.model;
    }

    public function set configuration(conf:XML):void {
        this.configurationObj = conf;
    }

    public function get configuration():XML {
        return this.configurationObj;
    }

    public function set providers(prov:ArrayCollection):void {
        this.providersObj = prov;
    }

    public function get providers():ArrayCollection {
        return this.providersObj;
    }

    public function set onError(error:FaultEvent):void {
        this.onErrorObj = error;
    }

    public function get onError():FaultEvent {
        return this.onErrorObj;
    }


    // getters delegates

    public function getLoadFileDelegate():ILoadFileDelegate {
        if (this.loadFileDelegate == null) {
            this.loadFileDelegate = new LoadFileDelegate();
        }
        return this.loadFileDelegate;
    }

    public function getLoadDatasDelegate():ILoadDatasDelegate {
        if (this.loadDatasDelegate == null) {
            this.loadDatasDelegate = new LoadDatasDelegate();
        }
        return this.loadDatasDelegate;
    }
    
    public function getLoadDataBaseDelegate():ILoadDataBaseDelegate {
        if (this.loadDataBaseDelegate == null) {
            this.loadDataBaseDelegate = new LoadDataBaseDelegate();
        }
        return this.loadDataBaseDelegate;
    }

    public function getStartMonitoringDelegate():IStartMonitoringDelegate {
        if (this.startMonitoringDelegate == null) {
            this.startMonitoringDelegate = new StartMonitoringDelegate();
        }
        return this.startMonitoringDelegate;
    }

    public function getStopMonitoringDelegate():IStopMonitoringDelegate {
        if (this.stopMonitoringDelegate == null) {
            this.stopMonitoringDelegate = new StopMonitoringDelegate();
        }
        return this.stopMonitoringDelegate;
    }


}
}
